Reading sensors

Dependencies:   mbed m3pi

Fork of 3pi_Lab1_Task2 by Craig Evans

Revision:
3:57544dc71dfc
Parent:
2:970ef3f79ac5
Child:
4:3edc12f142f3
--- a/main.cpp	Mon Jun 26 11:51:05 2017 +0000
+++ b/main.cpp	Thu Jun 29 09:45:46 2017 +0000
@@ -36,9 +36,7 @@
     // an array to store each of the sensor values
     unsigned int values[5]= {0};
     
-    
-    
-    float dt = 1.0/50.0;  // we'll read the sensor 50 times a second
+    float dt = 1.0/100.0;  // we'll read the sensors 100 times a second
 
     // main loop - this runs forever
     while(1) {